@@ -109,58 +109,65 @@ sub test_throw {
 sub test_with {
     my $self = shift;
 
-    eval {
-        my $obj1 = Exception::System->new(message=>'Message');
-        $obj1->{errstr} = 'Errstr';
-        $self->assert_equals(0, $obj1->with(undef));
-        $self->assert_equals(0, $obj1->with(message=>undef));
-        $self->assert_equals(1, $obj1->with('Message'));
-        $self->assert_equals(1, $obj1->with(message=>'Message'));
-        $self->assert_equals(0, $obj1->with(errstr=>undef));
-        $self->assert_equals(1, $obj1->with(errstr=>'Errstr'));
-        $self->assert_equals(1, $obj1->with(errstr=>sub {/Errstr/}));
-        $self->assert_equals(0, $obj1->with(errstr=>sub {/false/}));
-        $self->assert_equals(1, $obj1->with(errstr=>qr/Errstr/));
-        $self->assert_equals(0, $obj1->with(errstr=>qr/false/));
-    };
-    die "$@" if $@;
+    my $obj1 = Exception::System->new(message=>'Message');
+    $obj1->{errstr} = 'Errstr';
+    $obj1->{errno} = 123;
+    $self->assert_num_equals(0, $obj1->with(undef));
+    $self->assert_num_equals(0, $obj1->with(message=>undef));
+    $self->assert_num_equals(1, $obj1->with('Message: Errstr'));
+    $self->assert_num_equals(1, $obj1->with(123));
+    $self->assert_num_equals(1, $obj1->with(message=>'Message'));
+    $self->assert_num_equals(0, $obj1->with(errstr=>undef));
+    $self->assert_num_equals(1, $obj1->with(errstr=>'Errstr'));
+    $self->assert_num_equals(1, $obj1->with(errstr=>sub {/Errstr/}));
+    $self->assert_num_equals(0, $obj1->with(errstr=>sub {/false/}));
+    $self->assert_num_equals(1, $obj1->with(errstr=>qr/Errstr/));
+    $self->assert_num_equals(0, $obj1->with(errstr=>qr/false/));
+    $self->assert_num_equals(1, $obj1->with(errno=>123));
 }
 
 sub test_stringify {
     my $self = shift;
 
-    eval {
-        my $obj = Exception::System->new(message=>'Stringify');
+    my $obj = Exception::System->new(message=>'Stringify');
 
-        $self->assert_not_null($obj);
-        $self->assert($obj->isa("Exception::System"), '$obj->isa("Exception::System")');
-        $self->assert($obj->isa("Exception::Base"), '$obj->isa("Exception::Base")');
-        $self->assert_equals('', $obj->stringify(0));
-        $self->assert_equals("Stringify\n", $obj->stringify(1));
-        $self->assert_matches(qr/Stringify at .* line \d+.\n/s, $obj->stringify(2));
-        $self->assert_matches(qr/Exception::System: Stringify at .* line \d+\n/s, $obj->stringify(3));
-        $self->assert_equals("Message\n", $obj->stringify(1, "Message"));
-        $self->assert_equals("Unknown system exception\n", $obj->stringify(1, ""));
+    $self->assert_not_null($obj);
+    $self->assert($obj->isa("Exception::System"), '$obj->isa("Exception::System")');
+    $self->assert($obj->isa("Exception::Base"), '$obj->isa("Exception::Base")');
+    $self->assert_equals('', $obj->stringify(0));
+    $self->assert_equals("Stringify\n", $obj->stringify(1));
+    $self->assert_matches(qr/Stringify at .* line \d+.\n/s, $obj->stringify(2));
+    $self->assert_matches(qr/Exception::System: Stringify at .* line \d+\n/s, $obj->stringify(3));
+    $self->assert_equals("Message\n", $obj->stringify(1, "Message"));
+    $self->assert_equals("Unknown system exception\n", $obj->stringify(1, ""));
 
-        $obj->{errstr} = 'Error';
-        $self->assert_equals('', $obj->stringify(0));
-        $self->assert_equals("Stringify: Error\n", $obj->stringify(1));
-        $self->assert_matches(qr/Stringify: Error at .* line \d+.\n/s, $obj->stringify(2));
-        $self->assert_matches(qr/Exception::System: Stringify: Error at .* line \d+\n/s, $obj->stringify(3));
-        $self->assert_equals("Message: Error\n", $obj->stringify(1, "Message"));
-        $self->assert_equals("Error\n", $obj->stringify(1, ""));
+    $obj->{errstr} = 'Error';
+    $self->assert_equals('', $obj->stringify(0));
+    $self->assert_equals("Stringify: Error\n", $obj->stringify(1));
+    $self->assert_matches(qr/Stringify: Error at .* line \d+.\n/s, $obj->stringify(2));
+    $self->assert_matches(qr/Exception::System: Stringify: Error at .* line \d+\n/s, $obj->stringify(3));
+    $self->assert_equals("Message\n", $obj->stringify(1, "Message"));
+    $self->assert_equals("Unknown system exception\n", $obj->stringify(1, ""));
 
-        $self->assert_equals(1, $obj->{defaults}->{verbosity} = 1);
-        $self->assert_equals(1, $obj->{defaults}->{verbosity});
-        $self->assert_equals("Stringify: Error\n", $obj->stringify);
-        $self->assert_not_null($obj->{defaults}->{verbosity});
-        $obj->{defaults}->{verbosity} = Exception::System->ATTRS->{verbosity}->{default};
-        $self->assert_equals(1, $obj->{verbosity} = 1);
-        $self->assert_equals("Stringify: Error\n", $obj->stringify);
+    $self->assert_equals(1, $obj->{defaults}->{verbosity} = 1);
+    $self->assert_equals(1, $obj->{defaults}->{verbosity});
+    $self->assert_equals("Stringify: Error\n", $obj->stringify);
+    $self->assert_not_null($obj->{defaults}->{verbosity});
+    $obj->{defaults}->{verbosity} = Exception::System->ATTRS->{verbosity}->{default};
+    $self->assert_equals(1, $obj->{verbosity} = 1);
+    $self->assert_equals("Stringify: Error\n", $obj->stringify);
 
-        $self->assert_equals("Stringify: Error\n", "$obj");
-    };
-    die "$@" if $@;
+    $self->assert_equals("Stringify: Error\n", "$obj");
+}
+
+sub test_numerify {
+    my $self = shift;
+
+    my $obj = Exception::System->new;
+    $obj->{errno} = 123;    
+
+    $self->assert_num_equals(123, $obj->numerify);
+    $self->assert_num_equals(123, 0+$obj);
 }
 
 sub test_try {
@@ -171,7 +178,7 @@ sub test_try {
         my $v1 = Exception::System->try(eval { 1; });
         $self->assert_equals(1, $v1);
         my $e1 = Exception::System->catch(my $obj1);
-        $self->assert_equals(0, $e1);
+        $self->assert_equals('', $e1);
         $self->assert_null($obj1);
 
         eval { 1; };
@@ -182,8 +189,9 @@ sub test_try {
         $self->assert_not_null($obj2);
         $self->assert($obj2->isa("Exception::System"), '$obj2->isa("Exception::System")');
         $self->assert($obj2->isa("Exception::Base"), '$obj2->isa("Exception::Base")');
-        $self->assert_equals("Die 2\n", $obj2->{message});
-    }
+        $self->assert_equals("Die 2", $obj2->{message});
+    };
+    die "$@" if $@;
 }
 
 1;
